# BriCA V1

wbap/V1 repository contains a python implementation for BriCA V1

## Reference:
* [Tutorial](http://wbap.github.io/BriCA1/)
* [Wiki](http://wba-initiative.org/wiki/en/brica)

## Support:
If you have any question, please send us message on Google Group:  
https://groups.google.com/d/forum/wbai-dev
